# BPMN Tools

> a collection of tools to work with BPMN

[![Latest Version on PyPI](https://img.shields.io/pypi/v/bpmn-tools.svg)](https://pypi.python.org/pypi/bpmn-tools/)
[![Supported Implementations](https://img.shields.io/pypi/pyversions/bpmn-tools.svg)](https://pypi.python.org/pypi/bpmn-tools/)
![Build Status](https://github.com/christophevg/bpmn-tools/actions/workflows/test.yaml/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/bpmn-tools/badge/?version=latest)](https://bpmn-tools.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/christophevg/bpmn-tools/badge.svg?branch=master)](https://coveralls.io/github/christophevg/bpmn-tools?branch=master)
[![Built with PyPi Template](https://img.shields.io/badge/PyPi_Template-v0.5.0-blue.svg)](https://github.com/christophevg/pypi-template)



## Documentation

Visit [Read the Docs](https://bpmn-tools.readthedocs.org) for the full documentation, including overviews and several examples.


